set more off

* Core data analysis

use processeddata\Final_Anonymized_OriginalFieldExperimentDataset.dta, clear

****
*
* Table S2: Balance Tests for Original Experimental Sample
*
****

logit treatment race_* gender_* sd_*

outsum race_* gender_* sd_* if treatment==0 using Tables\TableS2.out, bracket ctitle("Control Group") replace
outsum race_* gender_* sd_* if treatment==1 using Tables\TableS2.out, bracket ctitle("Treatment Group") append
clear


use processeddata\Final_Anonymized_Analysis_Dataset.dta, clear

****
*
* Table S3: Balance Tests for Final Experimental Sample
*
****

gen sd_10=0
replace sd_10=1 if match_state=="TX"
label variable sd_10 "State==TX"

logit treatment race_* gender_* acs_* sd_*

outsum race_* gender_* acs_* sd_* if treatment==0 using Tables\TableS3.out, bracket ctitle("Control Group") replace
outsum race_* gender_* acs_* sd_* if treatment==1 using Tables\TableS3.out, bracket ctitle("Treatment Group") append
drop sd_10

****
*
* Figure S1: Observational analysis
*
****

rename outcome_felonrecord outcome_supervisionrecord
label var outcome_supervisionrecord "Under state supervision (1=yes)"

gen z = int(1000*place_felon_risk_score)
egen vmean=mean(g10), by(z)
sort place_felon_risk_score idnum
replace vmean=. if place_felon_risk_score==place_felon_risk_score[_n-1]

sort place_felon_risk_score g10 idnum
egen avg_contrisk_voted=mean(outcome_supervisionrecord) if g10==1, by(place_felon_risk_score)
egen weight_contrisk_voted=count(outcome_supervisionrecord) if g10==1, by(place_felon_risk_score)

egen avg_contrisk_notvoted=mean(outcome_supervisionrecord) if g10==0, by(place_felon_risk_score)
egen weight_contrisk_notvoted=count(outcome_supervisionrecord) if g10==0, by(place_felon_risk_score)

sort place_felon_risk_score g10 idnum
replace avg_contrisk_voted=. if avg_contrisk_voted~=. & place_felon_risk_score==place_felon_risk_score[_n-1] & g10==g10[_n-1]
replace avg_contrisk_notvoted=. if avg_contrisk_notvoted~=. & place_felon_risk_score==place_felon_risk_score[_n-1] & g10==g10[_n-1]

egen binavgvoted=mean(outcome_supervisionrecord) if g10==1, by(z)
sort g10 z binavgvoted idnum
replace binavgvoted=. if z==z[_n-1] & g10==g10[_n-1] 
egen binavgnotvoted=mean(outcome_supervisionrecord) if g10==0, by(z)
sort g10 z binavgnotvoted idnum
replace binavgnotvoted=. if z==z[_n-1] & g10==g10[_n-1] 

count
local temp1=r(N)
count if place_felon_risk_score<=.04
local temp2=100*r(N)/`temp1'
local tempstr = string(`temp2',"%9.0f")+"%"
di "`tempstr'"

keep if place_felon_risk_score<=.04

* This block of code adds the rugplot, each percentile of range of felon risk score
sort place_felon_risk_score idnum
count
gen temp=int(100*_n/_N)
replace temp=temp+1
replace temp=100 if temp==101
bysort temp: egen avg_bin_pfrs=mean(place_felon_risk_score)
sort temp idnum
replace avg_bin_pfrs=. if temp==temp[_n-1]
gen y=-.005

#delimit ;
twoway
(lpolyci avg_contrisk_voted place_felon_risk_score [aweight=weight_contrisk_voted], bwidth(.005) clcolor(black) clpattern(solid) fcolor(none) blcolor(black) blpattern(solid))
(lpolyci avg_contrisk_notvoted place_felon_risk_score [aweight=weight_contrisk_notvoted], bwidth(.005) clcolor(black) clpattern(dash) fcolor(none) blcolor(black) blpattern(dash))
(lpoly vmean place_felon_risk_score, lpattern(dot))
(scatter binavgvoted place_felon_risk_score if g10==1, mcolor(black) msize(medium) msymbol(+))
(scatter binavgnotvoted place_felon_risk_score if g10==0, mcolor(black) msize(medium) msymbol(Oh))
(scatter y avg_bin_pfrs , mcolor(black) msize(vsmall) msymbol(T))
if place_felon_risk_score<=.04,
ytitle(Proportion Voting/Under Criminal Supervision, size(small))
xtitle(Predicted Probability of Criminal Supervision, size(small)) xlabel(, labsize(small))
legend(col(2) label(2 "Voted in 2010") label(4 "Did not vote in 2010") label(5 "Proportion Voting") label(6 "") label(7 "") order(5 - - "Proportion supervised" "among those who" - 4 7 2 6) size(vsmall) textfirst)
note("Lines are local polynomials, with 95% confidence intervals for proportion under criminal supervision. Scatter plot is average in .001 unit bins.", size(vsmall) span)
caption("Analysis is for `tempstr' of sample with Predicted Probability of Criminal Supervision<=.04. Diamonds are distribution of data on X axis by percentile.", size(vsmall) span) 
title("Figure S1: Observational Relationship Between Voting and Criminal Behavior", size(vsmall))
subtitle("All States", size(vsmall))
xsize(9) ysize(6.5)
scheme(s1mono)
name(FigS01_SimpleDescrip, replace);
#delimit cr
graph export figures\FigS1.pdf, as(pdf) replace

clear
*/
****
*
* Figure S2: Observational analysis, Restricted to Texas, Ohio, and Washington so that we know not in prison in 2010
*
****

use processeddata\Final_Anonymized_Analysis_Dataset.dta, clear
keep if (match_state =="TX" | match_state =="OH" | match_state =="WA")
rename outcome_felonrecord outcome_supervisionrecord
label var outcome_supervisionrecord "Under state supervision (1=yes)"

gen z = int(1000*place_felon_risk_score)
egen vmean=mean(g10), by(z)
sort place_felon_risk_score idnum
replace vmean=. if place_felon_risk_score==place_felon_risk_score[_n-1]

sort place_felon_risk_score g10 idnum
egen avg_contrisk_voted=mean(outcome_supervisionrecord) if g10==1, by(place_felon_risk_score)
egen weight_contrisk_voted=count(outcome_supervisionrecord) if g10==1, by(place_felon_risk_score)

egen avg_contrisk_notvoted=mean(outcome_supervisionrecord) if g10==0, by(place_felon_risk_score)
egen weight_contrisk_notvoted=count(outcome_supervisionrecord) if g10==0, by(place_felon_risk_score)

sort place_felon_risk_score g10 idnum
replace avg_contrisk_voted=. if avg_contrisk_voted~=. & place_felon_risk_score==place_felon_risk_score[_n-1] & g10==g10[_n-1]
replace avg_contrisk_notvoted=. if avg_contrisk_notvoted~=. & place_felon_risk_score==place_felon_risk_score[_n-1] & g10==g10[_n-1]

egen binavgvoted=mean(outcome_supervisionrecord) if g10==1, by(z)
sort g10 z binavgvoted idnum
replace binavgvoted=. if z==z[_n-1] & g10==g10[_n-1] 
egen binavgnotvoted=mean(outcome_supervisionrecord) if g10==0, by(z)
sort g10 z binavgnotvoted idnum
replace binavgnotvoted=. if z==z[_n-1] & g10==g10[_n-1] 

count
local temp1=r(N)
count if place_felon_risk_score<=.02
local temp2=100*r(N)/`temp1'
local tempstr = string(`temp2',"%9.0f")+"%"
di "`tempstr'"

* This block of code adds the rugplot, each percentile of range of felon risk score
sort place_felon_risk_score idnum
count
gen temp=int(100*_n/_N)
replace temp=temp+1
replace temp=100 if temp==101
bysort temp: egen avg_bin_pfrs=mean(place_felon_risk_score)
sort temp idnum
replace avg_bin_pfrs=. if temp==temp[_n-1]
gen y=-.005

#delimit ;
twoway
(lpolyci avg_contrisk_voted place_felon_risk_score [aweight=weight_contrisk_voted], bwidth(.005) clcolor(black) clpattern(solid) fcolor(none) blcolor(black) blpattern(solid))
(lpolyci avg_contrisk_notvoted place_felon_risk_score [aweight=weight_contrisk_notvoted], bwidth(.005) clcolor(black) clpattern(dash) fcolor(none) blcolor(black) blpattern(dash))
(lpoly vmean place_felon_risk_score, lpattern(dot))
(scatter binavgvoted place_felon_risk_score if g10==1, mcolor(black) msize(medium) msymbol(+))
(scatter binavgnotvoted place_felon_risk_score if g10==0, mcolor(black) msize(medium) msymbol(Oh))
(scatter y avg_bin_pfrs , mcolor(black) msize(vsmall) msymbol(T))
if place_felon_risk_score<=.02,
ytitle(Proportion Voting/Under Criminal Supervision, size(small))
xtitle(Predicted Probability of Criminal Supervision, size(small)) xlabel(, labsize(small))
legend(col(2) label(2 "Voted in 2010") label(4 "Did not vote in 2010") label(5 "Proportion Voting") label(6 "") label(7 "") order(5 - - "Proportion supervised" "among those who" - 4 7 2 6) size(vsmall) textfirst)
note("Lines are local polynomials, with 95% confidence intervals for proportion under criminal supervision. Scatter plot is average in .001 unit bins.", size(vsmall) span)
title("Figure S2: Observational Relationship Between Voting and Criminal Behavior", size(vsmall))
subtitle("States where we know supervision post-dates 2010 election (Ohio, Texas, Washington)", size(vsmall))
caption("Diamonds are distribution of data on X axis by percentile.", size(vsmall) span) 
xsize(9) ysize(6.5)
scheme(s1mono)
name(Fig02_SimpleDescrip, replace);
#delimit cr
graph export figures\FigS2.pdf, as(pdf) replace
*/
clear

****
*
* Figure S3: Observational analysis, Restricted to Florida. More expansive coverage
*
****

use processeddata\Final_Anonymized_Analysis_Dataset.dta, clear
keep if (match_state =="FL")
rename outcome_felonrecord outcome_supervisionrecord
label var outcome_supervisionrecord "Under state supervision (1=yes)"

gen z = int(1000*place_felon_risk_score)
egen vmean=mean(g10), by(z)
sort place_felon_risk_score idnum
replace vmean=. if place_felon_risk_score==place_felon_risk_score[_n-1]

sort place_felon_risk_score g10 idnum
egen avg_contrisk_voted=mean(outcome_supervisionrecord) if g10==1, by(place_felon_risk_score)
egen weight_contrisk_voted=count(outcome_supervisionrecord) if g10==1, by(place_felon_risk_score)

egen avg_contrisk_notvoted=mean(outcome_supervisionrecord) if g10==0, by(place_felon_risk_score)
egen weight_contrisk_notvoted=count(outcome_supervisionrecord) if g10==0, by(place_felon_risk_score)

sort place_felon_risk_score g10 idnum
replace avg_contrisk_voted=. if avg_contrisk_voted~=. & place_felon_risk_score==place_felon_risk_score[_n-1] & g10==g10[_n-1]
replace avg_contrisk_notvoted=. if avg_contrisk_notvoted~=. & place_felon_risk_score==place_felon_risk_score[_n-1] & g10==g10[_n-1]

egen binavgvoted=mean(outcome_supervisionrecord) if g10==1, by(z)
sort g10 z binavgvoted idnum
replace binavgvoted=. if z==z[_n-1] & g10==g10[_n-1] 
egen binavgnotvoted=mean(outcome_supervisionrecord) if g10==0, by(z)
sort g10 z binavgnotvoted idnum
replace binavgnotvoted=. if z==z[_n-1] & g10==g10[_n-1] 

count
local temp1=r(N)
count if place_felon_risk_score<=.04
local temp2=100*r(N)/`temp1'
local tempstr = string(`temp2',"%9.0f")+"%"
di "`tempstr'"

* This block of code adds the rugplot, each percentile of range of felon risk score
sort place_felon_risk_score idnum
count
gen temp=int(100*_n/_N)
replace temp=temp+1
replace temp=100 if temp==101
bysort temp: egen avg_bin_pfrs=mean(place_felon_risk_score)
sort temp idnum
replace avg_bin_pfrs=. if temp==temp[_n-1]
gen y=-.005

#delimit ;
twoway
(lpolyci avg_contrisk_voted place_felon_risk_score [aweight=weight_contrisk_voted], bwidth(.005) clcolor(black) clpattern(solid) fcolor(none) blcolor(black) blpattern(solid))
(lpolyci avg_contrisk_notvoted place_felon_risk_score [aweight=weight_contrisk_notvoted], bwidth(.005) clcolor(black) clpattern(dash) fcolor(none) blcolor(black) blpattern(dash))
(lpoly vmean place_felon_risk_score, lpattern(dot))
(scatter binavgvoted place_felon_risk_score if g10==1, mcolor(black) msize(medium) msymbol(+))
(scatter binavgnotvoted place_felon_risk_score if g10==0, mcolor(black) msize(medium) msymbol(Oh))
(scatter y avg_bin_pfrs , mcolor(black) msize(vsmall) msymbol(T))
if place_felon_risk_score<=.04,
ytitle(Proportion Voting/Under Criminal Supervision, size(small))
xtitle(Predicted Probability of Criminal Supervision, size(small)) xlabel(, labsize(small))
legend(col(2) label(2 "Voted in 2010") label(4 "Did not vote in 2010") label(5 "Proportion Voting") label(6 "") label(7 "") order(5 - - "Proportion supervised" "among those who" - 4 7 2 6) size(vsmall) textfirst)
note("Lines are local polynomials, with 95% confidence intervals for proportion under criminal supervision. Scatter plot is average in .001 unit bins.", size(vsmall) span)
caption("Diamonds are distribution of data on X axis by percentile.", size(vsmall) span) 
title("Figure S3: Observational Relationship Between Voting and Criminal Behavior", size(vsmall))
subtitle("Including lower-level forms of state supervision (Florida)", size(vsmall))
scheme(s1mono)
xsize(9) ysize(6.5)
name(Fig03_SimpleDescrip, replace);
#delimit cr
graph export figures\FigS3.pdf, as(pdf) replace

****
*
* Analyses reported in text of SA4.
*
****

reg outcome_supervisionrecord g10 if place<.001, robust
reg outcome_supervisionrecord g10 if place>.009 & place<.011, robust
clear

****
*
* Table 2: Observational analysis
*
****
use processeddata\Final_Anonymized_Analysis_Dataset.dta, clear

gen outcome_supervisionrecord = outcome_felonrecord * 100
label var outcome_supervisionrecord "Under state supervision (100=yes)"

* observation effect of registration and voting on felon outcome
regress outcome_supervisionrecord race_* gender_* acs_* sd_*, robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\Table2.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) replace

* first run probit and calculate average mfx
probit outcome_supervisionrecord race_* gender_* acs_* sd_* g10, robust
gen temp2=g10
replace g10=1
predict p1 if e(sample)
replace g10=0
predict p0 if e(sample)
replace g10=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress outcome_supervisionrecord race_* gender_* acs_* sd_* g10, robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\Table2.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean), "MFX of Voted in 2010 from probit", `probitmfx') append

* first run probit and calculate average mfx
probit outcome_supervisionrecord race_* gender_* acs_* sd_* g10 if high_risk_sample==0, robust
gen temp2=g10
replace g10=1
predict p1 if e(sample)
replace g10=0
predict p0 if e(sample)
replace g10=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress outcome_supervisionrecord race_* gender_* acs_* sd_* g10 if high_risk_sample==0, robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\Table2.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean), "MFX of Voted in 2010 from probit", `probitmfx') append

* first run probit and calculate average mfx
probit outcome_supervisionrecord race_* gender_* acs_* sd_* g10 if high_risk_sample==1, robust
gen temp2=g10
replace g10=1
predict p1 if e(sample)
replace g10=0
predict p0 if e(sample)
replace g10=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress outcome_supervisionrecord race_* gender_* acs_* sd_* g10 if high_risk_sample==1, robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\Table2.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean), "MFX of Voted in 2010 from probit", `probitmfx') append

****
*
* Table S4: Robustness Table 2
*
****

regress outcome_supervisionrecord race_* gender_* acs_* sd_* outcome_isreg, robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS4.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) replace

regress outcome_supervisionrecord race_* gender_* acs_* sd_* outcome_isreg if high_risk_sample==0, robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS4.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress outcome_supervisionrecord race_* gender_* acs_* sd_* outcome_isreg if high_risk_sample==1, robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS4.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress outcome_supervisionrecord race_* gender_* acs_* sd_* outcome_isreg if (match_state =="TX" | match_state =="OH" | match_state =="WA"), robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS4.out", ctitle("OH, TX, WA: `note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress outcome_supervisionrecord race_* gender_* acs_* sd_* g10 if (match_state =="TX" | match_state =="OH" | match_state =="WA"), robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS4.out", ctitle("OH, TX, WA: `note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress outcome_supervisionrecord race_* gender_* acs_* sd_* outcome_isreg if (match_state =="FL"), robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS4.out", ctitle("FL: `note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress outcome_supervisionrecord race_* gender_* acs_* sd_* g10 if (match_state =="FL"), robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS4.out", ctitle("FL: `note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

****
*
* Table S5: State by State version of Table 2
*
****

levelsof match_state, local(levelslist)
* keep relevant states, those in felon database
foreach val of local levelslist {
 di "`val'"

 regress outcome_supervisionrecord race_* gender_* acs_* g10 if match_state=="`val'", robust
 local note : variable label outcome_supervisionrecord
 summ outcome_supervisionrecord if e(sample)

 if "`val'"=="AZ" {
  outreg2 using "Tables\TableS5.out", ctitle("`note', State=`val'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) replace
 }
 else {
  outreg2 using "Tables\TableS5.out", ctitle("`note', State=`val'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append
 }
 
}

****
*
* Table S6: Probit version of Table 2
*
****

* observation effect of registration and voting on felon outcome
probit outcome_supervisionrecord race_* gender_* acs_* sd_*, robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS6.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) replace

probit outcome_supervisionrecord race_* gender_* acs_* sd_* g10, robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS6.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

probit outcome_supervisionrecord race_* gender_* acs_* sd_* g10 if high_risk_sample==0, robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS6.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

probit outcome_supervisionrecord race_* gender_* acs_* sd_* g10 if high_risk_sample==1, robust
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS6.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

****
*
* Table 3: Field Experiment Effects on Voting
*
****

gen voted10=g10 * 100
label var voted10 "Voted in 2010 (100=yes)"
* first run probit and calculate average mfx
probit voted10 treatment race_* gender_* acs_* sd_* , robust cluster(hhid)
gen temp2=treatment
replace treatment=1
predict p1 if e(sample)
replace treatment=0
predict p0 if e(sample)
replace treatment=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress voted10 treatment race_* gender_* acs_* sd_* , robust cluster(hhid)
local fstat= e(F)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label voted10
summ voted10 if e(sample) & treatment==0
outreg2 using "Tables\Table3.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in control group", r(mean), "F-Statistic", `fstat', "F p-value",`fmodel', "MFX of Treatment from probit", `probitmfx') replace

* first run probit and calculate average mfx
probit voted10 treatment , robust cluster(hhid)
gen temp2=treatment
replace treatment=1
predict p1 if e(sample)
replace treatment=0
predict p0 if e(sample)
replace treatment=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress voted10 treatment , robust cluster(hhid)
local fstat= e(F)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label voted10
summ voted10 if e(sample) & treatment==0
outreg2 using "Tables\Table3.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in control group", r(mean), "F-Statistic", `fstat', "F p-value",`fmodel', "MFX of Treatment from probit", `probitmfx') append

* first run probit and calculate average mfx
probit voted10 treatment race_* gender_* acs_* sd_* if high_risk_sample==0, robust cluster(hhid)
gen temp2=treatment
replace treatment=1
predict p1 if e(sample)
replace treatment=0
predict p0 if e(sample)
replace treatment=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress voted10 treatment race_* gender_* acs_* sd_* if high_risk_sample==0, robust cluster(hhid)
local fstat= e(F)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label voted10
summ voted10 if e(sample) & treatment==0
outreg2 using "Tables\Table3.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in control group", r(mean), "F-Statistic", `fstat', "F p-value",`fmodel', "MFX of Treatment from probit", `probitmfx') append

* first run probit and calculate average mfx
probit voted10 treatment if high_risk_sample==0, robust cluster(hhid)
gen temp2=treatment
replace treatment=1
predict p1 if e(sample)
replace treatment=0
predict p0 if e(sample)
replace treatment=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress voted10 treatment if high_risk_sample==0, robust cluster(hhid)
local fstat= e(F)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label voted10
summ voted10 if e(sample) & treatment==0
outreg2 using "Tables\Table3.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in control group", r(mean), "F-Statistic", `fstat', "F p-value",`fmodel', "MFX of Treatment from probit", `probitmfx') append

* first run probit and calculate average mfx
probit voted10 treatment race_* gender_* acs_* sd_* if high_risk_sample==1, robust cluster(hhid)
gen temp2=treatment
replace treatment=1
predict p1 if e(sample)
replace treatment=0
predict p0 if e(sample)
replace treatment=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress voted10 treatment race_* gender_* acs_* sd_* if high_risk_sample==1, robust cluster(hhid)
local fstat= e(F)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label voted10
summ voted10 if e(sample) & treatment==0
outreg2 using "Tables\Table3.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in control group", r(mean), "F-Statistic", `fstat', "F p-value",`fmodel', "MFX of Treatment from probit", `probitmfx') append

* first run probit and calculate average mfx
probit voted10 treatment if high_risk_sample==1, robust cluster(hhid)
gen temp2=treatment
replace treatment=1
predict p1 if e(sample)
replace treatment=0
predict p0 if e(sample)
replace treatment=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress voted10 treatment if high_risk_sample==1, robust cluster(hhid)
local fstat= e(F)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label voted10
summ voted10 if e(sample) & treatment==0
outreg2 using "Tables\Table3.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in control group", r(mean), "F-Statistic", `fstat', "F p-value",`fmodel', "MFX of Treatment from probit", `probitmfx') append

****
*
* Table S7: Field Experiment Effects on Reg 
*
****

gen outcome_isreg10=outcome_isreg * 100
label var outcome_isreg10 "Registered in 2010 (100=yes)"

* predicting registration status with treatment
regress outcome_isreg10 treatment race_* gender_* acs_* sd_*, robust cluster(hhid)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label outcome_isreg
summ outcome_isreg10 if e(sample) & treatment==0
outreg2 using "Tables\TableS7.out", ctitle("`note'") se bracket bdec(3) tdec(6)  addstat("Mean of outcome in control group", r(mean), "F p-value",`fmodel') replace

regress outcome_isreg10 treatment, robust cluster(hhid)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label outcome_isreg
summ outcome_isreg10 if e(sample) & treatment==0
outreg2 using "Tables\TableS7.out", ctitle("`note'") se bracket bdec(3) tdec(6)  addstat("Mean of outcome in control group", r(mean), "F p-value",`fmodel') append

regress outcome_isreg10 treatment race_* gender_* acs_* sd_* if high_risk_sample==0, robust cluster(hhid)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label outcome_isreg
summ outcome_isreg10 if e(sample)
outreg2 using "Tables\TableS7.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6)  addstat("Mean of outcome in control group", r(mean), "F p-value",`fmodel') append

regress outcome_isreg10 treatment if high_risk_sample==0, robust cluster(hhid)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label outcome_isreg
summ outcome_isreg10 if e(sample)
outreg2 using "Tables\TableS7.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6)  addstat("Mean of outcome in control group", r(mean), "F p-value",`fmodel') append

regress outcome_isreg10 treatment race_* gender_* acs_* sd_* if high_risk_sample==1, robust cluster(hhid)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label outcome_isreg
summ outcome_isreg10 if e(sample)
outreg2 using "Tables\TableS7.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6)  addstat("Mean of outcome in control group", r(mean), "F p-value",`fmodel') append

regress outcome_isreg10 treatment if high_risk_sample==1, robust cluster(hhid)
local fmodel= Ftail(`e(df_m)',`e(df_r)',`e(F)')
local note : variable label outcome_isreg
summ outcome_isreg10 if e(sample)
outreg2 using "Tables\TableS7.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6)  addstat("Mean of outcome in control group", r(mean), "F p-value",`fmodel') append


****
*
* Table 4: Field Experiment Downstream Effects of Voting
*
****

* first run probit and calculate average mfx
probit outcome_supervisionrecord treatment race_* gender_* acs_* sd_*, robust cluster(hhid)
gen temp2=treatment
replace treatment=1
predict p1 if e(sample)
replace treatment=0
predict p0 if e(sample)
replace treatment=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress outcome_supervisionrecord treatment race_* gender_* acs_* sd_*, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\Table4.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean), "MFX of Treatment from probit", `probitmfx') replace

ivregress 2sls outcome_supervisionrecord race_* gender_* acs_* sd_* (g10  = treatment race_* gender_* acs_* sd_*), robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\Table4.out", ctitle("Instrumental Variables Regression (2SLS), `note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

* first run probit and calculate average mfx
probit  outcome_supervisionrecord treatment race_* gender_* acs_* sd_*  if high_risk_sample==0, robust cluster(hhid)
gen temp2=treatment
replace treatment=1
predict p1 if e(sample)
replace treatment=0
predict p0 if e(sample)
replace treatment=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress outcome_supervisionrecord treatment race_* gender_* acs_* sd_*  if high_risk_sample==0, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\Table4.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean), "MFX of Treatment from probit", `probitmfx')  append

ivregress 2sls outcome_supervisionrecord race_* gender_* acs_* sd_* (g10  = treatment race_* gender_* acs_* sd_*)  if high_risk_sample==0, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\Table4.out", ctitle("Instrumental Variables Regression (2SLS), `note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

* first run probit and calculate average mfx
probit outcome_supervisionrecord treatment race_* gender_* acs_* sd_*  if high_risk_sample==1, robust cluster(hhid)
gen temp2=treatment
replace treatment=1
predict p1 if e(sample)
replace treatment=0
predict p0 if e(sample)
replace treatment=temp2
gen z=(p1-p0)*100
summ z
local probitmfx = r(mean)
drop temp2 p1 p0 z
* ols
regress outcome_supervisionrecord treatment race_* gender_* acs_* sd_*  if high_risk_sample==1, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\Table4.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean), "MFX of Treatment from probit", `probitmfx')  append

ivregress 2sls outcome_supervisionrecord race_* gender_* acs_* sd_* (g10  = treatment race_* gender_* acs_* sd_*)  if high_risk_sample==1, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\Table4.out", ctitle("Instrumental Variables Regression (2SLS), `note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

****
*
* Table S8: Field Experiment Downstream Effects of Voting Robustness
*
****

regress outcome_supervisionrecord treatment race_* gender_* acs_* sd_*  if (match_state =="TX" | match_state =="OH" | match_state =="WA"), robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS8.out", ctitle("OH, TX, WA: `note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) replace

ivregress 2sls outcome_supervisionrecord race_* gender_* acs_* sd_* (g10  = treatment race_* gender_* acs_* sd_*)   if (match_state =="TX" | match_state =="OH" | match_state =="WA"), robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS8.out", ctitle("OH, TX, WA: Instrumental Variables Regression (2SLS), `note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress outcome_supervisionrecord treatment race_* gender_* acs_* sd_*  if (match_state =="FL"), robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS8.out", ctitle("FL: `note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

ivregress 2sls outcome_supervisionrecord race_* gender_* acs_* sd_* (g10  = treatment race_* gender_* acs_* sd_*)   if (match_state =="FL"), robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS8.out", ctitle("FL: Instrumental Variables Regression (2SLS), `note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

****
*
* Table S9: Tables 3 and 4 as probit
*
****

* predicting voting status with treatment
probit g10 treatment race_* gender_* acs_* sd_* , cluster(hhid)
local note : variable label g10
summ g10 if e(sample) & treatment==0
outreg2 using "Tables\TableS9.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in control group", r(mean)) replace

probit g10 treatment, cluster(hhid)
local note : variable label g10
summ outcome_isreg if e(sample) & treatment==0
outreg2 using "Tables\TableS9.out", ctitle("`note'") se bracket bdec(3) tdec(6)  addstat("Mean of outcome in control group", r(mean)) append

probit g10 treatment race_* gender_* acs_* sd_* if high_risk_sample==0, cluster(hhid)
local note : variable label g10
summ g10 if e(sample) & treatment==0
outreg2 using "Tables\TableS9.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in control group", r(mean)) append

probit g10 treatment if high_risk_sample==0, cluster(hhid)
local note : variable label g10
summ g10 if e(sample) & treatment==0
outreg2 using "Tables\TableS9.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in control group", r(mean)) append

probit g10 treatment race_* gender_* acs_* sd_* if high_risk_sample==1, cluster(hhid)
local note : variable label g10
summ g10 if e(sample) & treatment==0
outreg2 using "Tables\TableS9.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in control group", r(mean)) append

probit g10 treatment if high_risk_sample==1, cluster(hhid)
local note : variable label g10
summ outcome_isreg if e(sample)
outreg2 using "Tables\TableS9.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6)  addstat("Mean of outcome in control group", r(mean)) append

probit outcome_supervisionrecord treatment race_* gender_* acs_* sd_*, cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS9.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

probit outcome_supervisionrecord treatment race_* gender_* acs_* sd_*  if high_risk_sample==0, cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS9.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

probit outcome_supervisionrecord treatment race_* gender_* acs_* sd_*  if high_risk_sample==1, cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS9.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

****
*
* Table S10: Field Experiment Downstream Effects of Registering
*
****

ivregress 2sls outcome_supervisionrecord race_* gender_* acs_* sd_* (outcome_isreg  = treatment race_* gender_* acs_* sd_*), robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS10.out", ctitle("Instrumental Variables Regression (2SLS), `note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) replace

ivregress 2sls outcome_supervisionrecord race_* gender_* acs_* sd_* (outcome_isreg  = treatment race_* gender_* acs_* sd_*)  if high_risk_sample==0, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS10.out", ctitle("Instrumental Variables Regression (2SLS), `note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

ivregress 2sls outcome_supervisionrecord race_* gender_* acs_* sd_* (outcome_isreg  = treatment race_* gender_* acs_* sd_*)  if high_risk_sample==1, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS10.out", ctitle("Instrumental Variables Regression (2SLS), `note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

****
*
* Table S11: Tables 2 and 4 with more strict definition of felon record
*
****
label var strict_anyfelonmatch "Under state supervision, strict match (1=yes)"
gen strict_anyfelonmatch_final = strict_anyfelonmatch * 100
label var strict_anyfelonmatch_final "Under state supervision, strict match (100=yes)"

regress strict_anyfelonmatch_final race_* gender_* acs_* sd_* g10, robust
local note : variable label strict_anyfelonmatch_final
summ strict_anyfelonmatch_final if e(sample)
outreg2 using "Tables\TableS11.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) replace

regress strict_anyfelonmatch_final race_* gender_* acs_* sd_* g10 if high_risk_sample==0, robust
local note : variable label strict_anyfelonmatch_final
summ strict_anyfelonmatch_final if e(sample)
outreg2 using "Tables\TableS11.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress strict_anyfelonmatch_final race_* gender_* acs_* sd_* g10 if high_risk_sample==1, robust
local note : variable label strict_anyfelonmatch_final
summ strict_anyfelonmatch_final if e(sample)
outreg2 using "Tables\TableS11.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress strict_anyfelonmatch_final treatment race_* gender_* acs_* sd_*, robust cluster(hhid)
local note : variable label strict_anyfelonmatch_final
summ strict_anyfelonmatch_final if e(sample)
outreg2 using "Tables\TableS11.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

ivregress 2sls strict_anyfelonmatch_final race_* gender_* acs_* sd_* (g10  = treatment race_* gender_* acs_* sd_*), robust cluster(hhid)
local note : variable label strict_anyfelonmatch_final
summ strict_anyfelonmatch_final if e(sample)
outreg2 using "Tables\TableS11.out", ctitle("Instrumental Variables Regression (2SLS), `note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress strict_anyfelonmatch_final treatment race_* gender_* acs_* sd_*  if high_risk_sample==0, robust cluster(hhid)
local note : variable label strict_anyfelonmatch_final
summ strict_anyfelonmatch_final if e(sample)
outreg2 using "Tables\TableS11.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

ivregress 2sls strict_anyfelonmatch_final race_* gender_* acs_* sd_* (g10  = treatment race_* gender_* acs_* sd_*)  if high_risk_sample==0, robust cluster(hhid)
local note : variable label strict_anyfelonmatch_final
summ strict_anyfelonmatch_final if e(sample)
outreg2 using "Tables\TableS11.out", ctitle("Instrumental Variables Regression (2SLS), `note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress strict_anyfelonmatch_final treatment race_* gender_* acs_* sd_*  if high_risk_sample==1, robust cluster(hhid)
local note : variable label strict_anyfelonmatch_final
summ strict_anyfelonmatch_final if e(sample)
outreg2 using "Tables\TableS11.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

ivregress 2sls strict_anyfelonmatch_final race_* gender_* acs_* sd_* (g10  = treatment race_* gender_* acs_* sd_*)  if high_risk_sample==1, robust cluster(hhid)
local note : variable label strict_anyfelonmatch_final
summ strict_anyfelonmatch_final if e(sample)
outreg2 using "Tables\TableS11.out", ctitle("Instrumental Variables Regression (2SLS), `note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

****
*
* Table S12: Field Experiment Downstream Effects of Voting without covariates
*
****
regress outcome_supervisionrecord treatment sd_*, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS12.out", ctitle("`note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) replace

ivregress 2sls outcome_supervisionrecord sd_* (g10  = treatment sd_*), robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS12.out", ctitle("Instrumental Variables Regression (2SLS), `note'") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress outcome_supervisionrecord treatment sd_*  if high_risk_sample==0, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS12.out", ctitle("`note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

ivregress 2sls outcome_supervisionrecord sd_* (g10  = treatment sd_*)  if high_risk_sample==0, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS12.out", ctitle("Instrumental Variables Regression (2SLS), `note', low risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

regress outcome_supervisionrecord treatment sd_* if high_risk_sample==1, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS12.out", ctitle("`note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append

ivregress 2sls outcome_supervisionrecord sd_* (g10  = treatment sd_*)  if high_risk_sample==1, robust cluster(hhid)
local note : variable label outcome_supervisionrecord
summ outcome_supervisionrecord if e(sample)
outreg2 using "Tables\TableS12.out", ctitle("Instrumental Variables Regression (2SLS), `note', high risk sample") se bracket bdec(3) tdec(6) addstat("Mean of outcome in sample", r(mean)) append
